@@ -1,4 +1,4 @@
-# Copyright 2018 Splunk Inc. All rights reserved.
+# Copyright 2019 Splunk Inc. All rights reserved.
 
 """
 ### Calls to external data sources
@@ -6,6 +6,7 @@
 
 # Python Standard Libraries
 import logging
+
 # Custom Libraries
 import splunk_appinspect
 
@@ -13,9 +14,9 @@ logger = logging.getLogger(__name__)
 report_display_order = 12
 
 
-@splunk_appinspect.tags('splunk_appinspect', 'manual', 'appapproval')
-@splunk_appinspect.cert_version(min='1.0.0')
-def check_external_data_sources(app, reporter):
+@splunk_appinspect.tags("splunk_appinspect", "manual", "appapproval")
+@splunk_appinspect.cert_version(min="1.0.0")
+def check_external_data_sources(reporter):
     """Check that all external data sources are explained in the app's
     documentation.
     """
