@@ -1,4 +1,4 @@
-# Copyright 2018 Splunk Inc. All rights reserved.
+# Copyright 2019 Splunk Inc. All rights reserved.
 
 """
 ### JSON file standards
@@ -8,9 +8,10 @@
 import json
 import os
 import logging
+
+# Third-Party Libraries
 import six
-# Third-Party
-# N/A
+
 # Custom Modules
 import splunk_appinspect
 
@@ -19,14 +20,14 @@ logger = logging.getLogger(__name__)
 report_display_order = 13
 
 
-@splunk_appinspect.tags('splunk_appinspect', 'cloud')
-@splunk_appinspect.cert_version(min='1.1.0')
+@splunk_appinspect.tags("splunk_appinspect", "cloud")
+@splunk_appinspect.cert_version(min="1.1.0")
 def check_validate_json_data_is_well_formed(app, reporter):
     """Check that all JSON files are well formed."""
 
-    for dir, file, ext in app.iterate_files(types=['.json']):
-        current_file_relative_path = os.path.join(dir, file)
-        current_file_full_path = app.get_filename(dir, file)
+    for directory, file_name, _ in app.iterate_files(types=[".json"]):
+        current_file_relative_path = os.path.join(directory, file_name)
+        current_file_full_path = app.get_filename(directory, file_name)
 
         if six.PY2:
             with open(current_file_full_path, "r") as f:
@@ -37,8 +38,8 @@ def check_validate_json_data_is_well_formed(app, reporter):
 
         try:
             json.loads(current_file_contents)
-        except Exception as e:
-            reporter_output = ("Malformed JSON file found. "
-                               "File: {} "
-                               "Error: {}").format(current_file_relative_path, str(e))
+        except (TypeError, ValueError) as error:
+            reporter_output = (
+                "Malformed JSON file found. " "File: {} " "Error: {}"
+            ).format(current_file_relative_path, str(error))
             reporter.fail(reporter_output, current_file_relative_path)
