@@ -1,20 +1,28 @@
+"""
+Splunk App python file dependency manager module
+"""
+# Python Standard Libraries
 import os
 import itertools
 import logging
 import ast
 import platform
-import six
 import shutil
 import multiprocessing
+from lib2to3.main import main as exec_two_to_three
+
+# Third-Party Libraries
+import six
+from six import iteritems
+
+# Custom Libraries
+from splunk_appinspect.python_analyzer import utilities
+from splunk_appinspect.python_analyzer import ast_types
 
 
 if not platform.system() == "Windows":
     import magic
 
-from splunk_appinspect.python_analyzer import utilities
-from splunk_appinspect.python_analyzer import ast_types
-from six import iteritems
-from lib2to3.main import main as exec_two_to_three
 
 __all__ = ["FileDepManager"]
 
@@ -37,6 +45,7 @@ class FileDepManager(object):
         restriction_area (String): As described above.
         file_pool (Dict): The filepath->fileNode dictionary
     """
+
     def __init__(self, restriction_area=None, libs=None):
         if restriction_area:
             self.restriction_area = os.path.abspath(restriction_area)
@@ -53,6 +62,9 @@ class FileDepManager(object):
         self._python_files_in_circular_dependency = set()
 
     def flush(self):
+        """
+        clear all stored data
+        """
         self._file_pool.clear()
         self._user_friendly_dependency_graphs.clear()
         self._circular_dependency = None
@@ -86,6 +98,7 @@ class FileDepManager(object):
                 parent_stamp = self._file_pool[loop[i]].parent_stamps[parent_filenode]
                 loop_with_line_number.append((loop[i], parent_stamp))
             return loop_with_line_number
+
         if self._circular_dependency is None:
             self._populate_circular_dependency()
         loops_collection = []
@@ -114,7 +127,7 @@ class FileDepManager(object):
                             new_loop = ast_types.Stack()
                             new_loop.copy(loop).append(next_node.id)
                             stack.append((next_node, new_loop))
-            loops_collection.append(list(map(lambda tup: list(tup), loops)))
+            loops_collection.append([list(tup) for tup in loops])
         return loops_collection
 
     def __getitem__(self, filePath):
@@ -124,23 +137,24 @@ class FileDepManager(object):
         if filepath in self._user_friendly_dependency_graphs:
             return self._user_friendly_dependency_graphs[filepath]
         assert filepath in self._file_pool, "Please provide valid filepath."
-        # TODO assert not self.has_circular_dependency, "The graph has circular dependency." 
+        # TODO assert not self.has_circular_dependency, "The graph has circular dependency."
         dependency_tree = {}
         self._user_friendly_dependency_graphs[filepath] = dependency_tree
-        dependency_tree['filepath'] = filepath
-        dependency_tree['parents'] = []
+        dependency_tree["filepath"] = filepath
+        dependency_tree["parents"] = []
         for parent in self._file_pool[filepath].iter_parent():
-            dependency_tree['parents'].append(self.get_dependences(parent.filepath))
+            dependency_tree["parents"].append(self.get_dependences(parent.filepath))
         return dependency_tree
 
     def iter_files(self):
         return itertools.chain(
-                        self.iter_circular_dependency_files(),
-                        self.iter_non_circular_dependency_files())
+            self.iter_circular_dependency_files(),
+            self.iter_non_circular_dependency_files(),
+        )
 
     def iter_all_app_python_files(self):
-        for filepath in self._file_pool.keys():
-            yield filepath
+        for file_path in self._file_pool:
+            yield file_path
 
     def get_syntax_error_files(self):
         return self._syntax_error_file
@@ -160,20 +174,20 @@ class FileDepManager(object):
                 yield filepath
 
     def iter_non_circular_dependency_files(self):
-        '''
+        r"""
             Assume the file_pool is [a.py, b.py, c.py, d.py, e.py],
             whereas we have the following dependencies:
 
-                     a.py        d.py      e.py       
-                    /   \       /  
-                   /     \     /   
-                b.py       c.py   
-                        
+                     a.py        d.py      e.py
+                    /   \       /
+                   /     \     /
+                b.py       c.py
+
                     The lower depend on the upper
 
             The iterating order would be [a.py, b.py, d.py, c.py, e.py].
             Make sure to visit all its parents first before visit a node.
-        '''
+        """
         stack = []
         changeable_in_degree = {}
         # initialize in degree with default value
@@ -186,13 +200,17 @@ class FileDepManager(object):
                     changeable_in_degree[child_node] -= 1
         # start topological sort
         for _, file_node in iteritems(self._file_pool):
-            if changeable_in_degree[file_node] == 0 and (file_node not in self._python_files_in_circular_dependency):
+            if changeable_in_degree[file_node] == 0 and (
+                file_node not in self._python_files_in_circular_dependency
+            ):
                 stack.append(file_node)
         while stack:
             cur_file_node = stack.pop()
             for child_node in cur_file_node.iter_child():
                 changeable_in_degree[child_node] -= 1
-                if changeable_in_degree[child_node] == 0 and (child_node not in self._python_files_in_circular_dependency):
+                if changeable_in_degree[child_node] == 0 and (
+                    child_node not in self._python_files_in_circular_dependency
+                ):
                     stack.append(child_node)
             yield cur_file_node.filepath
 
@@ -226,14 +244,14 @@ class FileDepManager(object):
                     self._circular_dependency.append(cur_scc)
                     self._python_files_in_circular_dependency |= set(cur_scc)
 
-        for filepath, file_node in iteritems(self._file_pool):
+        for _, file_node in iteritems(self._file_pool):
             if file_node not in visited:
                 dfs(file_node)
 
     def add_file(self, filepath):
-        '''
+        """
             A file tree would be established based on the file's dependencies
-        '''
+        """
         filepath = os.path.abspath(filepath)
         if not os.path.isfile(filepath):
             raise Exception("{} not found or isn't file".format(filepath))
@@ -250,13 +268,23 @@ class FileDepManager(object):
                 # try to run 2to3 in python3 interpreter
                 try:
                     self._preprocess_file(filepath)
-                    if not eval(os.getenv('APPINSPECT_DISABLE_2TO3_CONCURRENCY', 'False')) and \
-                            multiprocessing.cpu_count() > 1 and \
-                            platform.system() != "Windows":
+                    if (
+                        not eval(
+                            os.getenv("APPINSPECT_DISABLE_2TO3_CONCURRENCY", "False")
+                        )
+                        and multiprocessing.cpu_count() > 1
+                        and platform.system() != "Windows"
+                    ):
 
-                        exec_two_to_three(fixer_pkg="lib2to3.fixes", args=["-w", filepath, "--no-diffs", "-j", "2"])
+                        exec_two_to_three(
+                            fixer_pkg="lib2to3.fixes",
+                            args=["-w", filepath, "--no-diffs", "-j", "2"],
+                        )
                     else:
-                        exec_two_to_three(fixer_pkg="lib2to3.fixes", args=["-w", filepath, "--no-diffs"])
+                        exec_two_to_three(
+                            fixer_pkg="lib2to3.fixes",
+                            args=["-w", filepath, "--no-diffs"],
+                        )
                     # retry find_imports again
                     deps = utilities.find_imports(filepath, self.libs)
                 except:
@@ -273,9 +301,14 @@ class FileDepManager(object):
         file_node = ast_types.FileNode(filepath)
         self._file_pool[filepath] = file_node
         for _, _, _, pkg_path, line_number in deps:
-            if not pkg_path \
-                or not pkg_path.endswith('.py') \
-                or (self.restriction_area and not pkg_path.startswith(self.restriction_area)):
+            if (
+                not pkg_path
+                or not pkg_path.endswith(".py")
+                or (
+                    self.restriction_area
+                    and not pkg_path.startswith(self.restriction_area)
+                )
+            ):
                 continue
             par_node = self.add_file(pkg_path)
             if par_node is not None and (filepath != pkg_path):
@@ -285,8 +318,13 @@ class FileDepManager(object):
     def add_folder(self, folder_path):
         counter = 0
         folder_path = os.path.abspath(folder_path)
-        for root, _, files in os.walk(folder_path, topdown=False,
-                                      onerror=lambda error: logger.warning('Walk App folder failed , `{}`'.format(error.strerror))):
+        for root, _, files in os.walk(
+            folder_path,
+            topdown=False,
+            onerror=lambda error: logger.warning(
+                "Walk App folder failed , `%s`", error.strerror
+            ),
+        ):
             for file_name in files:
                 file_path = os.path.join(root, file_name)
                 if file_name.endswith(".py"):
@@ -298,12 +336,23 @@ class FileDepManager(object):
                 else:
                     # check if it is hidden python file
                     window_filter_exts = [".conf"]
-                    if (not platform.system() == "Windows" and magic.from_file(file_path, mime=True).lower() == 'text/x-python') or \
-                            (platform.system() == "Windows" and
-                             (not any(map(lambda ext: file_path.endswith(ext), window_filter_exts))) and
-                             file_path.startswith(os.path.join(folder_path, 'bin'))):
+                    if (
+                        not platform.system() == "Windows"
+                        and magic.from_file(file_path, mime=True).lower()
+                        == "text/x-python"
+                    ) or (
+                        platform.system() == "Windows"
+                        and (
+                            not any(
+                                map(
+                                    lambda ext: file_path.endswith(ext),
+                                    window_filter_exts,
+                                )
+                            )
+                        )
+                    ):
                         try:
-                            ast.parse(open(file_path, mode='rb').read())
+                            ast.parse(open(file_path, mode="rb").read())
                             counter += 1
                             self.add_file(file_path)
                         except:
@@ -311,23 +360,40 @@ class FileDepManager(object):
                             if not six.PY2:
                                 try:
                                     self._preprocess_file(file_path)
-                                    if not eval(os.getenv('APPINSPECT_DISABLE_2TO3_CONCURRENCY', 'False')) and \
-                                            multiprocessing.cpu_count() > 1 and \
-                                            platform.system() != "Windows":
+                                    if (
+                                        not eval(
+                                            os.getenv(
+                                                "APPINSPECT_DISABLE_2TO3_CONCURRENCY",
+                                                "False",
+                                            )
+                                        )
+                                        and multiprocessing.cpu_count() > 1
+                                        and platform.system() != "Windows"
+                                    ):
 
-                                        exec_two_to_three(fixer_pkg="lib2to3.fixes",
-                                                        args=["-w", file_path, "--no-diffs", "-j", "2"])
+                                        exec_two_to_three(
+                                            fixer_pkg="lib2to3.fixes",
+                                            args=[
+                                                "-w",
+                                                file_path,
+                                                "--no-diffs",
+                                                "-j",
+                                                "2",
+                                            ],
+                                        )
                                     else:
-                                        exec_two_to_three(fixer_pkg="lib2to3.fixes",
-                                                          args=["-w", file_path, "--no-diffs"])
+                                        exec_two_to_three(
+                                            fixer_pkg="lib2to3.fixes",
+                                            args=["-w", file_path, "--no-diffs"],
+                                        )
 
-                                    ast.parse(open(file_path, mode='rb').read())
+                                    ast.parse(open(file_path, mode="rb").read())
                                     counter += 1
                                     self.add_file(file_path)
                                 except:
                                     # 2to3 parser and python3 parser are more stricter
                                     # stored in syntax error file to guarantee we won't leave it out
-                                    if file_path.endswith('.py'):
+                                    if file_path.endswith(".py"):
                                         self._syntax_error_file.add(file_path)
                                     else:
                                         self._hidden_python_file.add(file_path)
@@ -339,29 +405,29 @@ class FileDepManager(object):
         self._populate_circular_dependency()
         return counter
 
-
     @staticmethod
     def _preprocess_file(file_path):
         lines = []
         with open(file_path, "rb") as fr:
             for line in fr.readlines():
-                comps = line.split(b'\t')
+                comps = line.split(b"\t")
                 if len(comps) == 1:
                     lines.append(line)
                 else:
                     converted_comps = []
-                    for comp in comps[0: - 1]:
+                    for comp in comps[0:-1]:
                         offset = (1 + len(comp)) % 8
                         offset = (8 - offset) if offset else offset
-                        converted_comps.append(comp + b' ' + b' ' * offset)
+                        converted_comps.append(comp + b" " + b" " * offset)
 
-                    lines.append(b''.join(converted_comps) + comps[-1])
+                    lines.append(b"".join(converted_comps) + comps[-1])
 
-        shutil.copy(file_path, file_path + '.raw')
+        shutil.copy(file_path, file_path + ".raw")
 
         with open(file_path, "wb") as fw:
             fw.writelines(lines)
 
+
 class _Node(object):
     def __init__(self, id):
         self.id = id
